'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hash = hash;
exports.compare = compare;
exports.reset = reset;
exports.update = update;

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var bcrypt = _bluebird2.default.promisifyAll(require('bcryptjs'));
var crypto = _bluebird2.default.promisifyAll(require('crypto'));
var SALT_WORK_FACTOR = 10;

function hash(user) {
  if (!user.password) throw new Error('No password provided');
  return bcrypt.genSaltAsync(SALT_WORK_FACTOR).then(function (salt) {
    return bcrypt.hashAsync(user.password, salt);
  }).then(function (hash) {
    return user.password = hash;
  });
}

function compare(user, password) {
  return bcrypt.compareAsync(password, user.password);
}

function reset(user) {
  return crypto.randomBytesAsync(20).then(function (buffer) {
    var token = buffer.toString('hex');
    user.resetPasswordToken = token;
    user.resetPasswordExpires = Date.now() + 3600000;
    return token;
  });
}

function update(user, password) {
  user.password = password;
  user.resetPasswordToken = undefined;
  user.resetPasswordExpires = undefined;
  return hash(user).then(function () {
    return user;
  });
}

exports.default = { hash: hash, compare: compare, reset: reset, update: update };